/* pokefinder.h: help with finding pokes
   Copyright (c) 2003-2004 Philip Kendall

   $Id: pokefinder.h,v 1.2 2004/03/09 16:13:43 pak21 Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

   Author contact information:

   E-mail: pak21-fuse@srcf.ucam.org
   Postal address: 15 Crescent Road, Wokingham, Berks, RG40 2DB, England

*/

#ifndef FUSE_POKEFINDER_H
#define FUSE_POKEFINDER_H

#include <libspectrum.h>

extern int pokefinder_possible[8][0x4000];
extern size_t pokefinder_count;

int pokefinder_clear( void );
int pokefinder_search( libspectrum_byte value );
int pokefinder_incremented( void );
int pokefinder_decremented( void );

#endif				/* #ifndef FUSE_POKEFINDER_H */
